@@ -1,4 +1,5 @@
 from os.path import join
+from pathlib import Path
 from typing import List
 
 from guet import constants
@@ -7,4 +8,4 @@ from guet.files.write_lines import write_lines
 
 
 def set_errors(error_lines: List[str]):
-    write_lines(join(CONFIGURATION_DIRECTORY, constants.ERRORS), error_lines)
+    write_lines(Path(join(CONFIGURATION_DIRECTORY, constants.ERRORS)), error_lines)
