@@ -9,7 +9,8 @@ def log_on_error(wrapped):
             wrapped()
         # pylint: disable=broad-except
         except Exception:
-            print('An error has occurred, please refer to error logs (~/.guet/errors) for more information\n')
+            print(('An error has occurred, please refer to error '
+                   'logs (~/.guet/errors) for more information\n'))
             stack_tract: str = traceback.format_exc()
             set_errors(stack_tract.split('\n'))
             exit(1)
